Intel-XE Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Rodrigo Vivi <rodrigo.vivi@intel.com>
To: <intel-xe@lists.freedesktop.org>
Cc: kamil.kopryk@intel.com, filip.hazubski@intel.com,
	Francois Dugast <francois.dugast@intel.com>,
	jakub.chaberek@intel.com, effie.yu@intel.com,
	bartosz.dunajski@intel.com, Rodrigo Vivi <rodrigo.vivi@intel.com>,
	carl.zhang@intel.com
Subject: [Intel-xe] [PATCH 11/17] drm/xe/uapi: Use common drm_xe_ext_set_property extension
Date: Tue, 19 Sep 2023 10:24:58 -0400	[thread overview]
Message-ID: <20230919142504.91652-12-rodrigo.vivi@intel.com> (raw)
In-Reply-To: <20230919142504.91652-1-rodrigo.vivi@intel.com>

From: Ashutosh Dixit <ashutosh.dixit@intel.com>

There really is no difference between 'struct drm_xe_ext_vm_set_property'
and 'struct drm_xe_ext_exec_queue_set_property', they are extensions which
specify a <property, value> pair. Replace the two extensions with a single
common 'struct drm_xe_ext_set_property' extension. The rationale is that
rather than have each XE module (including future modules) invent their own
property/value extensions, all XE modules use a common set_property
extension when possible.

Signed-off-by: Ashutosh Dixit <ashutosh.dixit@intel.com>
Signed-off-by: Francois Dugast <francois.dugast@intel.com>
Signed-off-by: Rodrigo Vivi <rodrigo.vivi@intel.com>
---
 drivers/gpu/drm/xe/xe_exec_queue.c |  2 +-
 drivers/gpu/drm/xe/xe_vm.c         |  2 +-
 include/uapi/drm/xe_drm.h          | 21 +++------------------
 3 files changed, 5 insertions(+), 20 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_exec_queue.c b/drivers/gpu/drm/xe/xe_exec_queue.c
index f70332986c73..411ba38cb2b8 100644
--- a/drivers/gpu/drm/xe/xe_exec_queue.c
+++ b/drivers/gpu/drm/xe/xe_exec_queue.c
@@ -418,7 +418,7 @@ static int exec_queue_user_ext_set_property(struct xe_device *xe,
 					    bool create)
 {
 	u64 __user *address = u64_to_user_ptr(extension);
-	struct drm_xe_ext_exec_queue_set_property ext;
+	struct drm_xe_ext_set_property ext;
 	int err;
 	u32 idx;
 
diff --git a/drivers/gpu/drm/xe/xe_vm.c b/drivers/gpu/drm/xe/xe_vm.c
index 2af331cf2d35..33a02aca8971 100644
--- a/drivers/gpu/drm/xe/xe_vm.c
+++ b/drivers/gpu/drm/xe/xe_vm.c
@@ -1935,7 +1935,7 @@ static int vm_user_ext_set_property(struct xe_device *xe, struct xe_vm *vm,
 				    u64 extension)
 {
 	u64 __user *address = u64_to_user_ptr(extension);
-	struct drm_xe_ext_vm_set_property ext;
+	struct drm_xe_ext_set_property ext;
 	int err;
 
 	err = __copy_from_user(&ext, address, sizeof(ext));
diff --git a/include/uapi/drm/xe_drm.h b/include/uapi/drm/xe_drm.h
index fb7c3a8ac572..8be3b25928bd 100644
--- a/include/uapi/drm/xe_drm.h
+++ b/include/uapi/drm/xe_drm.h
@@ -572,12 +572,11 @@ struct drm_xe_vm_bind_op_error_capture {
 	__u64 size;
 };
 
-/** struct drm_xe_ext_vm_set_property - VM set property extension */
-struct drm_xe_ext_vm_set_property {
+/** struct drm_xe_ext_set_property - XE set property extension */
+struct drm_xe_ext_set_property {
 	/** @base: base user extension */
 	struct xe_user_extension base;
 
-#define XE_VM_PROPERTY_BIND_OP_ERROR_CAPTURE_ADDRESS		0
 	/** @property: property to set */
 	__u32 property;
 
@@ -593,6 +592,7 @@ struct drm_xe_ext_vm_set_property {
 
 struct drm_xe_vm_create {
 #define XE_VM_EXTENSION_SET_PROPERTY	0
+#define XE_VM_PROPERTY_BIND_OP_ERROR_CAPTURE_ADDRESS		0
 	/** @extensions: Pointer to the first extension struct, if any */
 	__u64 extensions;
 
@@ -757,21 +757,6 @@ struct drm_xe_vm_bind {
 	__u64 reserved[2];
 };
 
-/** struct drm_xe_ext_exec_queue_set_property - exec queue set property extension */
-struct drm_xe_ext_exec_queue_set_property {
-	/** @base: base user extension */
-	struct xe_user_extension base;
-
-	/** @property: property to set */
-	__u32 property;
-
-	/** @pad: MBZ */
-	__u32 pad;
-
-	/** @value: property value */
-	__u64 value;
-};
-
 /**
  * struct drm_xe_exec_queue_set_property - exec queue set property
  *
-- 
2.41.0


  parent reply	other threads:[~2023-09-19 14:26 UTC|newest]

Thread overview: 36+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-09-19 14:24 [Intel-xe] [PATCH 00/17] uAPI Alignment - take 1 Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 01/17] drm/xe: Fix array bounds check for queries Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 02/17] drm/xe: Set the correct type for xe_to_user_engine_class Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 03/17] drm/xe: Correlate engine and cpu timestamps with better accuracy Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 04/17] drm/xe/uapi: Separate VM_BIND's operation and flag Rodrigo Vivi
2023-09-19 20:39   ` Matthew Brost
2023-09-19 14:24 ` [Intel-xe] [PATCH 05/17] drm/xe/vm: Remove VM_BIND_OP macro Rodrigo Vivi
2023-09-19 14:41   ` Matthew Brost
2023-09-19 14:24 ` [Intel-xe] [PATCH 06/17] drm/xe/uapi: Remove MMIO ioctl Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 07/17] drm/xe: Fix xe_exec_queue_is_idle for parallel exec queues Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 08/17] drm/xe: Deprecate XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_MODE implementation Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 09/17] drm/xe: Rename exec_queue_kill_compute to xe_vm_remove_compute_exec_queue Rodrigo Vivi
2023-09-19 14:24 ` [Intel-xe] [PATCH 10/17] drm/xe: Remove XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_MODE from uAPI Rodrigo Vivi
2023-10-07  8:20   ` Zhang, Carl
2023-10-09 17:43     ` Francois Dugast
2023-09-19 14:24 ` Rodrigo Vivi [this message]
2023-09-19 20:41   ` [Intel-xe] [PATCH 11/17] drm/xe/uapi: Use common drm_xe_ext_set_property extension Matthew Brost
2023-09-19 14:24 ` [Intel-xe] [PATCH 12/17] drm/xe: Kill XE_VM_PROPERTY_BIND_OP_ERROR_CAPTURE_ADDRESS extension Rodrigo Vivi
2023-10-07  8:35   ` Zhang, Carl
2023-09-19 14:25 ` [Intel-xe] [PATCH 13/17] drm/xe/uapi: Document drm_xe_query_gt Rodrigo Vivi
2023-09-19 14:48   ` Matthew Brost
2023-09-19 14:25 ` [Intel-xe] [PATCH 14/17] drm/xe/uapi: Replace useless 'instance' per unique gt_id Rodrigo Vivi
2023-09-19 20:44   ` Matthew Brost
2023-09-19 14:25 ` [Intel-xe] [PATCH 15/17] drm/xe/uapi: Remove unused field of drm_xe_query_gt Rodrigo Vivi
2023-09-19 20:52   ` Matthew Brost
2023-09-19 14:25 ` [Intel-xe] [PATCH 16/17] drm/xe/uapi: Rename gts to gt_list Rodrigo Vivi
2023-09-19 14:25 ` [Intel-xe] [PATCH 17/17] drm/xe/uapi: Fix naming of XE_QUERY_CONFIG_MAX_EXEC_QUEUE_PRIORITY Rodrigo Vivi
2023-09-19 14:44   ` Matthew Brost
2023-09-19 14:32 ` [Intel-xe] ✓ CI.Patch_applied: success for uAPI Alignment - take 1 Patchwork
2023-09-19 14:32 ` [Intel-xe] ✗ CI.checkpatch: warning " Patchwork
2023-09-19 14:33 ` [Intel-xe] ✓ CI.KUnit: success " Patchwork
2023-09-19 14:42 ` [Intel-xe] ✗ CI.Build: failure " Patchwork
2023-09-19 17:19 ` [Intel-xe] [PATCH 00/17] " Souza, Jose
2023-09-21 15:06 ` Zhang, Carl
2023-09-22 18:56   ` Rodrigo Vivi
2023-10-08  8:06     ` Zhang, Carl

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230919142504.91652-12-rodrigo.vivi@intel.com \
    --to=rodrigo.vivi@intel.com \
    --cc=bartosz.dunajski@intel.com \
    --cc=carl.zhang@intel.com \
    --cc=effie.yu@intel.com \
    --cc=filip.hazubski@intel.com \
    --cc=francois.dugast@intel.com \
    --cc=intel-xe@lists.freedesktop.org \
    --cc=jakub.chaberek@intel.com \
    --cc=kamil.kopryk@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox